Documentation
¶
Overview ¶
Package amqp provide auto reconnect for rabbitmq
Index ¶
- type RabbitMQ
- func (r *RabbitMQ) Consume(consumer string, autoAck, exclusive, noLocal, noWait bool, ...) (<-chan amqp.Delivery, error)
- func (r *RabbitMQ) ExchangeDeclare(name, exchangeType string, durable, autoDelete, internal, noWait bool, ...) error
- func (r *RabbitMQ) Qos(prefetchCount, prefetchSize int, global bool) error
- func (r *RabbitMQ) QueueBind(key, exchangeName string, noWait bool, arguments amqp.Table) error
- func (r *RabbitMQ) QueueDeclare(name string, durable, autoDelete, exclusive, noWait bool, arguments amqp.Table) error
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type RabbitMQ ¶
type RabbitMQ struct {
Connection *amqp.Connection
Channel *amqp.Channel
// contains filtered or unexported fields
}
RabbitMQ contains Connection and Channel
func (*RabbitMQ) Consume ¶
func (r *RabbitMQ) Consume(consumer string, autoAck, exclusive, noLocal, noWait bool, arguments amqp.Table) (<-chan amqp.Delivery, error)
Consume starts delivering queued messages
func (*RabbitMQ) ExchangeDeclare ¶
func (r *RabbitMQ) ExchangeDeclare(name, exchangeType string, durable, autoDelete, internal, noWait bool, arguments amqp.Table) error
ExchangeDeclare declare an exchange
func (*RabbitMQ) Qos ¶
Qos controls how many messages or how many bytes the server will try to keep on the network for consumers before receiving delivery ack
Click to show internal directories.
Click to hide internal directories.